Module input

Module input 

Input API.

Functions

get_mouse_x
Get current mouse X position.
get_mouse_y
Get current mouse Y position.
is_button_down
Returns true if the specified button is currently held down.
is_key_down
Returns true if the specified key is currently held down.
is_mouse_down
Returns true if the specified mouse button is held down. 0 = Left, 1 = Right, 2 = Middle.