Input API.
Functions
- get_
mouse_ x - Get current mouse X position.
- get_
mouse_ y - Get current mouse Y position.
- is_
button_ down - Returns true if the specified button is currently held down.
- is_
key_ down - Returns true if the specified key is currently held down.
- is_
mouse_ down - Returns true if the specified mouse button is held down. 0 = Left, 1 = Right, 2 = Middle.